@@ -437,6 +437,7 @@ async def _mikrotik_probe(host,
                             raise
                         except Exception as err:
                             last_err = err
+                            return None
                         client = mikrotik_api
                         return client
                 except (MikrotikApiError, OSError, asyncio.TimeoutError) as err:
@@ -452,7 +453,7 @@ async def _mikrotik_probe(host,
 async def mikrotik_api_probe(host,
                              mikrotik_api_cls,
                              creds,
-                             raise_errors=True,
+                             raise_errors=False,
                              **kwargs):
     """Try to connect to a Mikrotik host using a list of (username, password) credentials."""
     pend = [
@@ -467,7 +468,16 @@ async def mikrotik_api_probe(host,
         done, pend = await asyncio.wait(pend, return_when=asyncio.FIRST_COMPLETED)
         while done:
             task = done.pop()
-            result = task.result()
+            try:
+                result = task.result()
+            except asyncio.CancelledError:
+                [x.cancel() for x in done]
+                [x.cancel() for x in pend]
+                raise
+            except:
+                if raise_errors and not client and not done and not pend:
+                    raise  # this is the last result, all results were errors.
+                result = None
             if result:
                 if client:
                     await result.close()
