@@ -1113,6 +1113,26 @@ class TestModelSync(unittest.TestCase):
             self.assertEqual(msvc.inactive_time, t)
         self._await(test())
 
+    def test_service_deactivation_disabled(self):
+        """Service deactivation can be disabled to leave old services created."""
+        async def test():
+            # create a service
+            accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
+            service = Service('service01', account_id='acct01', package_id=None, download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service.attachment.cpe_mac_address = '00:01:02:03:04:05'
+            services = {'service01': service}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, services=services, deactivate=False)
+            await self.checkSourceService(service)
+
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], services={}, deactivate=False)
+            services = {x.source_id: x for x in await self.model.Service.List(company_uuid=self.company.uuid)}
+            await self.checkSourceService(service)
+            msvc = services.get(service.id)
+            self.assertIsNotNone(msvc)
+            self.assertEqual(msvc.inactive, False)
+            self.assertEqual(msvc.inactive_time, None)
+        self._await(test())
+
     def test_service_reactivation(self):
         """A service can be reactivated."""
         async def test():
